.. currentmodule:: sardana.macroserver.msmetamacro

:mod:`~sardana.macroserver.msmetamacro`
===========================================

.. automodule:: sardana.macroserver.msmetamacro

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MacroLibrary`
    * :class:`MacroClass`
    * :class:`MacroFunction`

MacroLibrary
--------------------

.. autoclass:: MacroLibrary
    :show-inheritance:
    :members:

Parameterizable
--------------------

.. autoclass:: Parameterizable
    :show-inheritance:
    :members:
    
MacroClass
--------------------

.. autoclass:: MacroClass
    :show-inheritance:
    :members:

MacroFunction
--------------------

.. autoclass:: MacroFunction
    :show-inheritance:
    :members:
